@@ -2,7 +2,7 @@
 # The most bare-bone versions of the test runner support
 #
 import click
-from junitparser import TestCase, TestSuite
+from junitparser import TestCase, TestSuite # type: ignore
 
 from . import launchable
 from ..testpath import TestPath
